pub struct DeviceGetDvfsInfoRequest {
pub power_domain: PowerDomain,
}Fields
power_domain: PowerDomainTrait Implementations
Sourceimpl Clone for DeviceGetDvfsInfoRequest
impl Clone for DeviceGetDvfsInfoRequest
Sourcefn clone(&self) -> DeviceGetDvfsInfoRequest
fn clone(&self) -> DeviceGetDvfsInfoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceGetDvfsInfoRequest
Sourceimpl Debug for DeviceGetDvfsInfoRequest
impl Debug for DeviceGetDvfsInfoRequest
Sourceimpl<D> Decode<DeviceGetDvfsInfoRequest, D> for DeviceGetDvfsInfoRequestwhere
D: ResourceDialect,
impl<D> Decode<DeviceGetDvfsInfoRequest, D> for DeviceGetDvfsInfoRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DeviceGetDvfsInfoRequest
fn new_empty() -> DeviceGetDvfsInfoRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DeviceGetDvfsInfoRequest, D> for &DeviceGetDvfsInfoRequestwhere
D: ResourceDialect,
impl<D> Encode<DeviceGetDvfsInfoRequest, D> for &DeviceGetDvfsInfoRequestwhere
D: ResourceDialect,
impl Eq for DeviceGetDvfsInfoRequest
Sourceimpl Hash for DeviceGetDvfsInfoRequest
impl Hash for DeviceGetDvfsInfoRequest
Sourceimpl Ord for DeviceGetDvfsInfoRequest
impl Ord for DeviceGetDvfsInfoRequest
Sourcefn cmp(&self, other: &DeviceGetDvfsInfoRequest) -> Ordering
fn cmp(&self, other: &DeviceGetDvfsInfoRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetDvfsInfoRequest
impl PartialEq for DeviceGetDvfsInfoRequest
Sourcefn eq(&self, other: &DeviceGetDvfsInfoRequest) -> bool
fn eq(&self, other: &DeviceGetDvfsInfoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetDvfsInfoRequest
impl PartialOrd for DeviceGetDvfsInfoRequest
impl Persistable for DeviceGetDvfsInfoRequest
impl StructuralPartialEq for DeviceGetDvfsInfoRequest
Sourceimpl TypeMarker for DeviceGetDvfsInfoRequest
impl TypeMarker for DeviceGetDvfsInfoRequest
Sourcetype Owned = DeviceGetDvfsInfoRequest
type Owned = DeviceGetDvfsInfoRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceGetDvfsInfoRequest
impl ValueTypeMarker for DeviceGetDvfsInfoRequest
Sourcetype Borrowed<'a> = &'a DeviceGetDvfsInfoRequest
type Borrowed<'a> = &'a DeviceGetDvfsInfoRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DeviceGetDvfsInfoRequest as TypeMarker>::Owned,
) -> <DeviceGetDvfsInfoRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DeviceGetDvfsInfoRequest as TypeMarker>::Owned, ) -> <DeviceGetDvfsInfoRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DeviceGetDvfsInfoRequest
impl RefUnwindSafe for DeviceGetDvfsInfoRequest
impl Send for DeviceGetDvfsInfoRequest
impl Sync for DeviceGetDvfsInfoRequest
impl Unpin for DeviceGetDvfsInfoRequest
impl UnsafeUnpin for DeviceGetDvfsInfoRequest
impl UnwindSafe for DeviceGetDvfsInfoRequest