pub struct DeviceGetDvfsInfoResponder { /* private fields */ }Implementations
Sourceimpl DeviceGetDvfsInfoResponder
impl DeviceGetDvfsInfoResponder
Sourcepub fn send(
self,
status: i32,
info: Option<&OperatingPoint>,
) -> Result<(), Error>
pub fn send( self, status: i32, info: Option<&OperatingPoint>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
status: i32,
info: Option<&OperatingPoint>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, status: i32, info: Option<&OperatingPoint>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.