pub struct DeviceGetStateChangeEventResponse {
pub status: i32,
pub handle: Option<Event>,
}Fields
status: i32handle: Option<Event>Trait Implementations
Sourceimpl Decode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for DeviceGetStateChangeEventResponse
impl Decode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for DeviceGetStateChangeEventResponse
Sourceimpl Encode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for &mut DeviceGetStateChangeEventResponse
impl Encode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for &mut DeviceGetStateChangeEventResponse
Sourceimpl<T0: Encode<i32, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<Event, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<i32, DefaultFuchsiaResourceDialect>, T1: Encode<Optional<HandleType<Event, { _ }, 2147483648>>, DefaultFuchsiaResourceDialect>> Encode<DeviceGetStateChangeEventResponse, DefaultFuchsiaResourceDialect> for (T0, T1)
impl Eq for DeviceGetStateChangeEventResponse
Sourceimpl Ord for DeviceGetStateChangeEventResponse
impl Ord for DeviceGetStateChangeEventResponse
Sourcefn cmp(&self, other: &DeviceGetStateChangeEventResponse) -> Ordering
fn cmp(&self, other: &DeviceGetStateChangeEventResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetStateChangeEventResponse
impl PartialEq for DeviceGetStateChangeEventResponse
Sourcefn eq(&self, other: &DeviceGetStateChangeEventResponse) -> bool
fn eq(&self, other: &DeviceGetStateChangeEventResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetStateChangeEventResponse
impl PartialOrd for DeviceGetStateChangeEventResponse
Sourceimpl ResourceTypeMarker for DeviceGetStateChangeEventResponse
impl ResourceTypeMarker for DeviceGetStateChangeEventResponse
Sourcetype Borrowed<'a> = &'a mut DeviceGetStateChangeEventResponse
type Borrowed<'a> = &'a mut DeviceGetStateChangeEventResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for DeviceGetStateChangeEventResponse
impl StructuralPartialEq for DeviceGetStateChangeEventResponse
Sourceimpl TypeMarker for DeviceGetStateChangeEventResponse
impl TypeMarker for DeviceGetStateChangeEventResponse
Sourcetype Owned = DeviceGetStateChangeEventResponse
type Owned = DeviceGetStateChangeEventResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for DeviceGetStateChangeEventResponse
impl RefUnwindSafe for DeviceGetStateChangeEventResponse
impl Send for DeviceGetStateChangeEventResponse
impl Sync for DeviceGetStateChangeEventResponse
impl Unpin for DeviceGetStateChangeEventResponse
impl UnsafeUnpin for DeviceGetStateChangeEventResponse
impl UnwindSafe for DeviceGetStateChangeEventResponse