pub struct DeviceSetDvfsOperatingPointRequest {
pub op_idx: u16,
pub power_domain: PowerDomain,
}Fields
op_idx: u16power_domain: PowerDomainTrait Implementations
Sourceimpl Clone for DeviceSetDvfsOperatingPointRequest
impl Clone for DeviceSetDvfsOperatingPointRequest
Sourcefn clone(&self) -> DeviceSetDvfsOperatingPointRequest
fn clone(&self) -> DeviceSetDvfsOperatingPointRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceSetDvfsOperatingPointRequest
Sourceimpl<D> Decode<DeviceSetDvfsOperatingPointRequest, D> for DeviceSetDvfsOperatingPointRequestwhere
D: ResourceDialect,
impl<D> Decode<DeviceSetDvfsOperatingPointRequest, D> for DeviceSetDvfsOperatingPointRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> DeviceSetDvfsOperatingPointRequest
fn new_empty() -> DeviceSetDvfsOperatingPointRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DeviceSetDvfsOperatingPointRequest, D> for &DeviceSetDvfsOperatingPointRequestwhere
D: ResourceDialect,
impl<D> Encode<DeviceSetDvfsOperatingPointRequest, D> for &DeviceSetDvfsOperatingPointRequestwhere
D: ResourceDialect,
impl Eq for DeviceSetDvfsOperatingPointRequest
Sourceimpl Ord for DeviceSetDvfsOperatingPointRequest
impl Ord for DeviceSetDvfsOperatingPointRequest
Sourcefn cmp(&self, other: &DeviceSetDvfsOperatingPointRequest) -> Ordering
fn cmp(&self, other: &DeviceSetDvfsOperatingPointRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceSetDvfsOperatingPointRequest
impl PartialEq for DeviceSetDvfsOperatingPointRequest
Sourcefn eq(&self, other: &DeviceSetDvfsOperatingPointRequest) -> bool
fn eq(&self, other: &DeviceSetDvfsOperatingPointRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceSetDvfsOperatingPointRequest
impl PartialOrd for DeviceSetDvfsOperatingPointRequest
impl Persistable for DeviceSetDvfsOperatingPointRequest
impl StructuralPartialEq for DeviceSetDvfsOperatingPointRequest
Sourceimpl TypeMarker for DeviceSetDvfsOperatingPointRequest
impl TypeMarker for DeviceSetDvfsOperatingPointRequest
Sourcetype Owned = DeviceSetDvfsOperatingPointRequest
type Owned = DeviceSetDvfsOperatingPointRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceSetDvfsOperatingPointRequest
impl ValueTypeMarker for DeviceSetDvfsOperatingPointRequest
Sourcetype Borrowed<'a> = &'a DeviceSetDvfsOperatingPointRequest
type Borrowed<'a> = &'a DeviceSetDvfsOperatingPointRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DeviceSetDvfsOperatingPointRequest as TypeMarker>::Owned,
) -> <DeviceSetDvfsOperatingPointRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DeviceSetDvfsOperatingPointRequest as TypeMarker>::Owned, ) -> <DeviceSetDvfsOperatingPointRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DeviceSetDvfsOperatingPointRequest
impl RefUnwindSafe for DeviceSetDvfsOperatingPointRequest
impl Send for DeviceSetDvfsOperatingPointRequest
impl Sync for DeviceSetDvfsOperatingPointRequest
impl Unpin for DeviceSetDvfsOperatingPointRequest
impl UnsafeUnpin for DeviceSetDvfsOperatingPointRequest
impl UnwindSafe for DeviceSetDvfsOperatingPointRequest