#[repr(C)]pub struct DeviceSetTripCelsiusResponse {
pub status: i32,
}Fields
status: i32Trait Implementations
Sourceimpl Clone for DeviceSetTripCelsiusResponse
impl Clone for DeviceSetTripCelsiusResponse
Sourcefn clone(&self) -> DeviceSetTripCelsiusResponse
fn clone(&self) -> DeviceSetTripCelsiusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceSetTripCelsiusResponse
Sourceimpl Debug for DeviceSetTripCelsiusResponse
impl Debug for DeviceSetTripCelsiusResponse
Sourceimpl<D> Decode<DeviceSetTripCelsiusResponse, D> for DeviceSetTripCelsiusResponsewhere
D: ResourceDialect,
impl<D> Decode<DeviceSetTripCelsiusResponse, D> for DeviceSetTripCelsiusResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> DeviceSetTripCelsiusResponse
fn new_empty() -> DeviceSetTripCelsiusResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<DeviceSetTripCelsiusResponse, D> for &DeviceSetTripCelsiusResponsewhere
D: ResourceDialect,
impl<D> Encode<DeviceSetTripCelsiusResponse, D> for &DeviceSetTripCelsiusResponsewhere
D: ResourceDialect,
impl Eq for DeviceSetTripCelsiusResponse
Sourceimpl Hash for DeviceSetTripCelsiusResponse
impl Hash for DeviceSetTripCelsiusResponse
Sourceimpl Ord for DeviceSetTripCelsiusResponse
impl Ord for DeviceSetTripCelsiusResponse
Sourcefn cmp(&self, other: &DeviceSetTripCelsiusResponse) -> Ordering
fn cmp(&self, other: &DeviceSetTripCelsiusResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceSetTripCelsiusResponse
impl PartialEq for DeviceSetTripCelsiusResponse
Sourcefn eq(&self, other: &DeviceSetTripCelsiusResponse) -> bool
fn eq(&self, other: &DeviceSetTripCelsiusResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceSetTripCelsiusResponse
impl PartialOrd for DeviceSetTripCelsiusResponse
impl Persistable for DeviceSetTripCelsiusResponse
impl StructuralPartialEq for DeviceSetTripCelsiusResponse
Sourceimpl TypeMarker for DeviceSetTripCelsiusResponse
impl TypeMarker for DeviceSetTripCelsiusResponse
Sourcetype Owned = DeviceSetTripCelsiusResponse
type Owned = DeviceSetTripCelsiusResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceSetTripCelsiusResponse
impl ValueTypeMarker for DeviceSetTripCelsiusResponse
Sourcetype Borrowed<'a> = &'a DeviceSetTripCelsiusResponse
type Borrowed<'a> = &'a DeviceSetTripCelsiusResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<DeviceSetTripCelsiusResponse as TypeMarker>::Owned,
) -> <DeviceSetTripCelsiusResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<DeviceSetTripCelsiusResponse as TypeMarker>::Owned, ) -> <DeviceSetTripCelsiusResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for DeviceSetTripCelsiusResponse
impl RefUnwindSafe for DeviceSetTripCelsiusResponse
impl Send for DeviceSetTripCelsiusResponse
impl Sync for DeviceSetTripCelsiusResponse
impl Unpin for DeviceSetTripCelsiusResponse
impl UnsafeUnpin for DeviceSetTripCelsiusResponse
impl UnwindSafe for DeviceSetTripCelsiusResponse